## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Tests for students and related.
"""
import unittest
from StringIO import StringIO
from zope.app.testing.functional import FunctionalTestCase
from zope.component import (
    provideAdapter, adapts, getGlobalSiteManager, provideUtility)
from zope.component.hooks import setSite
from zope.component.interfaces import IFactory
from zope.interface import verify, implements
from zope.location.interfaces import ILocation
from zope.publisher.base import TestRequest
from zope.publisher.interfaces import NotFound
from waeup.sirp.students.student import (
    Student, StudentFactory,
    )
from waeup.sirp.students.interfaces import (
    IStudent,
    )
from waeup.sirp.testing import FunctionalLayer

class StudentTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        super(StudentTest, self).setUp()
        self.student = Student()
        return

    def tearDown(self):
        super(StudentTest, self).tearDown()
        return

    def test_interfaces(self):
        verify.verifyClass(IStudent, Student)
        verify.verifyObject(IStudent, self.student)
        return

class StudentFactoryTest(FunctionalTestCase):

    layer = FunctionalLayer

    def setUp(self):
        self.factory = StudentFactory()

    def tearDown(self):
        pass

    def test_interfaces(self):
        verify.verifyClass(IFactory, StudentFactory)
        verify.verifyObject(IFactory, self.factory)

    def test_factory(self):
        obj = self.factory()
        assert isinstance(obj, Student)

    def test_getInterfaces(self):
        implemented_by = self.factory.getInterfaces()
        assert implemented_by.isOrExtends(IStudent)
